# Notes
# There is a code outline right next to "source" icon. it is a table fo content
#Inputs----
file_Kawanda_Ntugamo_in <- "./Nutrition_and_weevils/data/raw/Nutrient_ommision_trials.csv"
file_Kawanda_in <- "./Nutrition_and_weevils/data/raw/Potassium_response_trial.csv"

#Outputs----
file_Kawanda_Ntugamo_out <- "./Nutrition_and_weevils/data/processed/2_Nutrient_ommision_trials.csv"
file_Kawanda_out <- "./Nutrition_and_weevils/data/processed/2_Potassium_response_trial.csv"

# Import data----
# Ntungamo-Kawanda trial
dat <- data.table::fread(file_Kawanda_Ntugamo_in)
# Kawanda trial
dt <- data.table::fread(file_Kawanda_in)

# Wrangle data----
## Ntungamo-Kawanda trial----
### Change structure----
dat <- dat %>% 
  mutate_if(is.character, as.factor) %>%    # character to factor
  mutate(Block = as.factor(Block)) %>%      # block as a factor
  mutate_at(vars(K:P), factor) %>%          # variables btn K to P to factor
  mutate(Spray = as.factor(Spray),          # Spray to factor
                Cycle = as.factor(Cycle),   # cycle to factor
                Trt   = factor(Trt))        # Trt to factor
setDT(dat)
### Get weevil damage----
dat[,XT := (UXI+UXO+LXI+LXO)/4]             # average of UXI,UXO,LXO and LXI
dat$XT <- as.integer(round(dat$XT))         # round & make integer
dat <- dat %>% filter(XT < 50)              # drop some outliers

### Rename variables ----
setnames(dat, c("Spray","Micro_nutrients"),
         c("Insecticide", "Other_nutrients"))

### Intuitive variables----
names(dat)
glimpse(dat)
dat$labels <- as.factor(paste0(dat$K,"K_", dat$N,"N_", dat$P,"P_", 
                               dat$Other_nutrients,"Ot_", dat$Insecticide, "SP"))

dat <- dat %>% 
  mutate(Plot = as.factor(Trt),
         Block = as.factor(Block),
         Trt   = as.factor(Trt),
         Mat   =  as.factor(Mat),
         Cycle = as.numeric(Cycle))
dat$Trts <- dat$labels  # assign labels to trts

### Save----
fwrite(dat, file_Kawanda_Ntugamo_out)

## Kawanda trial----
### Change str of variables----
dt1 <- dt %>%
  mutate(across(where(is.character), str_trim)) %>% #remove white spaces
  filter(LXI != "NA") %>% 
  mutate(Block = as.factor(Block),
         Trt   = as.factor(Trt),
         Mat = as.factor(Matno),
         Cycle = as.numeric(Cycle)) %>% 
  as.data.table()

### Get weevil damge----
dt2 <- dt1 %>% .[,XT := (UXI + UXO + LXI + LXO)/4] %>%
  .[, XT := as.integer(round(XT))]             #keep as integer

### Decode trts----
# K_levels
dt3 <- dt2 %>% 
  mutate(K_level = case_when(
    Trt == "1"  | Trt == "2"   | Trt == "9"  | Trt == "10" ~ "0K",   
    Trt == "3"  | Trt == "4"   | Trt == "11" | Trt == "12" ~ "75K",
    Trt == "5"  | Trt == "6"   | Trt == "13" | Trt == "14" ~ "150K",
    Trt == "7"  | Trt == "15"   ~ "250K",
    Trt == "8"  | Trt == "16"   ~ "600K",
    Trt == "17" | Trt == "18" |Trt == "19" | Trt == "20" ~ "00_0K",
    TRUE                        ~ "other")) %>% 
  as.data.table(.) %>%
  .[, K_level := as.factor(K_level)] %>% 
  filter(K_level != "other")

# Water levels
dt4 <- dt3 %>% 
  mutate(Water = case_when(
    Trt == "1"  | Trt == "2"   | Trt == "3"  | Trt == "4"|Trt == "17"    ~ 
      "Irrigated",   
    Trt == "5"  | Trt == "6"   | Trt == "7" | Trt == "8"|Trt == "19"     ~ 
      "Irrigated",
    Trt == "9"  | Trt == "10"   | Trt == "11"  | Trt == "12"|Trt == "18" ~ 
      "Rain-fed",   
    Trt == "13"  | Trt == "14"   | Trt == "15" | Trt == "16"|Trt == "20" ~ 
      "Rain-fed",
    TRUE                        ~ "other")) %>% 
  as.data.table(.) %>%
  .[, Water := as.factor(Water)] %>% 
  filter(Water != "other")

# Silicon levels
dt5 <- dt4 %>%
  mutate(Si = case_when(
    Trt == "2"  | Trt == "4"   | Trt == "6"| Trt == "7"| Trt == "8"    ~ "0Si",
    Trt == "10"  | Trt == "12" | Trt == "14"| Trt == "15"| Trt == "16" ~ "0Si",
    Trt == "1"  | Trt == "3"   | Trt == "5"    ~ "300Si",
    Trt == "9"  | Trt == "11"   | Trt == "13"  ~ "300Si",
    Trt == "17" | Trt == "18" |Trt == "19" | Trt == "20" ~ "0Si",
    TRUE                        ~ "other")) %>%
  as.data.table(.) %>%
  .[, Si := as.factor(Si)] %>%
  filter(Si != "other")

### Rename Trt as Plot----
setnames(dt5, "Trt","Plot")

# Drop some data points
dt6 <- dt5 %>% 
  filter(Matno != "133G") %>% 
  filter(Matno != "148G") %>%
  filter(Matno != "28G") %>%
  filter(Matno != "90G") %>%
  filter(Matno != "G") %>%               # guard rows not necessary here
  filter(Cycle != "1.1") %>%           
  filter(Cycle != "11") %>%             # 1.1 & 11 were corm_removal not needed
  filter(K_level != "00_0K") %>%        # not used to compare K levels
  mutate(fcycle = as.factor(Cycle)) %>% # make cycle as a factor
  filter(fcycle != "4")                 # too few (3) observations in cycle 4

### K & Si as continuous----
# Si
dti <- dt6 %>% 
  mutate(Silicon = case_when(
    Si == "0Si" ~ "0",
    Si  == "300Si" ~ "300")) %>% 
  mutate(Silicon = as.numeric(as.character(Silicon)))
# K
dti2 <- dti %>% 
  mutate(Potassium = case_when(
    K_level  == "0K" ~ "0",
    K_level  == "75K" ~ "75",
    K_level  == "150K" ~ "150",
    K_level  == "250K" ~ "250",
    K_level  == "600K" ~ "600"
  )) %>% 
  mutate(Potassium = as.numeric(as.character(Potassium)))

### Intuitive labels----
# easier to see plots this way
dti2$Trts <- paste0(dti2$Water,"_",dti2$Si,"_",dti2$K_level)

# order the Trts
dti2$Trts <-   fct_relevel(dti2$Trts,
                           "Rain-fed_0Si_0K","Rain-fed_0Si_75K",
                           "Rain-fed_0Si_150K","Rain-fed_0Si_250K",
                           "Rain-fed_0Si_600K","Rain-fed_300Si_0K",
                           "Rain-fed_300Si_75K","Rain-fed_300Si_150K",
                           "Irrigated_0Si_0K", "Irrigated_0Si_75K",
                           "Irrigated_0Si_150K","Irrigated_0Si_250K", 
                           "Irrigated_0Si_600K","Irrigated_300Si_0K",
                           "Irrigated_300Si_75K","Irrigated_300Si_150K")
### Save----
fwrite(dti2, file_Kawanda_out)