# Notes
# This script analyses data from the Ntungamo_Kawanda trial.
# To navigate the code use the scrip outline right next to "source" icon

#Inputs-----
file_Kawanda_Ntugamo_in <- "./Nutrition_and_weevils/data/processed/2_Nutrient_ommision_trials.csv"

# Outputs----
Fig_1 <- "./Nutrition_and_weevils/results/figures/3_Insecticide & N on weevils damage.tiff"

# Ecdf function----
stat_myecdf <- function(mapping = NULL, data = NULL, geom = "step",
                        position = "identity", n = NULL, na.rm = FALSE,
                        show.legend = NA, inherit.aes = TRUE, direction="vh", ...) {
  layer(
    data = data,
    mapping = mapping,
    stat = StatMyecdf,
    geom = geom,
    position = position,
    show.legend = show.legend,
    inherit.aes = inherit.aes,
    params = list(
      n = n,
      na.rm = na.rm,
      direction=direction,
      ...
    )
  )
}

StatMyecdf <- ggproto("StatMyecdf", Stat,
                      compute_group = function(data, scales, n = NULL) {
                        
                        # If n is NULL, use raw values; otherwise interpolate
                        if (is.null(n)) {
                          # Dont understand why but this version needs to sort the values
                          xvals <- sort(unique(data$x))
                        } else {
                          xvals <- seq(min(data$x), max(data$x), length.out = n)
                        }
                        
                        y <- ecdf(data$x)(xvals)
                        x1 <- max(xvals)
                        y0 <- 0                      
                        data.frame(x = c(xvals, x1), y = c(y0, y))
                      },
                      
                      default_aes = aes(y = ..y..),
                      
                      required_aes = c("x")
)

# Import data----
dtt <- fread(file_Kawanda_Ntugamo_in) %>% 
  glimpse()

# variable str----
dtt2 <- dtt %>% mutate_if(is.character, factor) %>% 
  mutate(Block = as.factor(Block),
         Trt = as.factor(Trt),
         Plot = as.factor(Plot),
         fcycle = as.factor(Cycle),
         Season = as.factor(Season),
         Insecticide = as.factor(Insecticide),
         Other_nutrients = as.factor(Other_nutrients),
         N = as.factor(N),
         K = as.factor(K),
         P = as.factor(P)
         )
glimpse(dtt2)

dat <- dtt2
levels(dat$labels)
## Cumulative distribution (ecdf)-----
#### Spray Effect ----
# select only sprayed vs non sprayed without other treatments
dursban1 <- dat %>% 
  filter(labels == "0K_0N_0P_0Ot_0SP" | labels == "0K_0N_0P_0Ot_1SP")

# Plot the difference between sprayed or not sprayed
ecdf_gg_Spray <- dursban1 %>%  
  ggplot(aes(x=XT, linetype = Insecticide))+ 
  geom_line(stat="myecdf", aes(linetype = Insecticide),size = .6)+
  scale_linetype_manual(name = c(""),
                     labels = c("Not sprayed", "Sprayed"),
                     values=c('dashed', 'solid'))+
  labs(x = "Weevil damage (%)",y = "Proportion of population") +
  theme_custom() +
  theme(text = element_text(family="sans",size=14),
        legend.key.width = unit(1.5, 'cm'),
        legend.position = c(.6,.4), legend.direction = "vertical",
        legend.key.size = unit(1.5, 'lines'),
        panel.background = element_rect(fill = "white"),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank())
ecdf_gg_Spray

### Nitrogen levels ----
# select only sprayed levels
# compare treatments where only nitrogen is changing
#### N effects only----
sprayed <- dat %>% filter(Insecticide == 1)
levels(dat$labels)
dt2 <- sprayed %>% 
  filter(labels == "600K_0N_50P_1Ot_1SP"| labels == 
           "600K_150N_50P_1Ot_1SP"| labels == "600K_400N_50P_1Ot_1SP")
ecdf_gg_N <- dt2 %>%  
  ggplot(aes(x=XT, col= N))+ 
  geom_line(stat="myecdf", aes(linetype = N),color = "black",size = .6) +
  scale_linetype_manual(name = c(""),
                        labels = c(expression(~ ~ paste("0 kg N ", ~ ha^-1, ~ yr^-1)),
                                   expression(~ ~ paste("150 kg N ", ~ ha^-1, ~  yr^-1)),
                                   expression(~ ~ paste(" 400 kg N ",~ ha^-1, ~ yr^-1))),
                        values=c("solid", "longdash","dotdash"))+
  labs(x = "Weevil damage (%)") +
  theme_custom() +
  theme(text = element_text(family="sans", size=14),
        legend.key.width = unit(1.5, 'cm'),
        legend.position = c(.6,.4), legend.direction = "vertical",
        legend.key.size = unit(1.3, 'lines'),
        panel.background = element_rect(fill = "white"),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank(),
        axis.text.y  = element_blank(),
        axis.title.y = element_blank())
ecdf_gg_N

## Combined plots----
# Spray, N, P and K plots
ecdf2 <- ecdf_gg_Spray+ecdf_gg_N
ecdf2 <- ecdf2 + plot_annotation(tag_levels = 'A')
ecdf2
ggsave(plot = ecdf2, Fig_1,  dpi = 600, width = 8, height = 5)

