# Notes
# There is a code outline right next to "source" icon. it is a table fo content

# Inputs-----
file_Kawanda_Ntugamo_in <- "./Nutrition_and_weevils/data/processed/2_Potassium_response_trial.csv"

#Outputs----
Fig_1 <- "./Nutrition_and_weevils/results/figures/4_K&Si by Water on weevils damage4.tiff"
Fig_2 <- "./Nutrition_and_weevils/results/figures/4_K&Si by Water on weevils damage5.tiff"

# Ecdf function----
stat_myecdf <- function(mapping = NULL, data = NULL, geom = "step",
                        position = "identity", n = NULL, na.rm = FALSE,
                        show.legend = NA, inherit.aes = TRUE, direction="vh",
                        ...) {
  layer(
    data = data,
    mapping = mapping,
    stat = StatMyecdf,
    geom = geom,
    position = position,
    show.legend = show.legend,
    inherit.aes = inherit.aes,
    params = list(
      n = n,
      na.rm = na.rm,
      direction=direction,
      ...
    )
  )
}

StatMyecdf <- ggproto("StatMyecdf", Stat,
                      compute_group = function(data, scales, n = NULL) {
                        
                        # If n is NULL, use raw values; otherwise interpolate
                        if (is.null(n)) {
                          # Dont understand why but this version needs to sort the values
                          xvals <- sort(unique(data$x))
                        } else {
                          xvals <- seq(min(data$x), max(data$x), length.out = n)
                        }
                        
                        y <- ecdf(data$x)(xvals)
                        x1 <- max(xvals)
                        y0 <- 0                      
                        data.frame(x = c(xvals, x1), y = c(y0, y))
                      },
                      
                      default_aes = aes(y = ..y..),
                      
                      required_aes = c("x")
)

# visual elements
axis_text <- element_text(color = "black", size = 11)

# Kawanda field trial----
## Import data----
dti2 <- fread(file_Kawanda_Ntugamo_in) 
glimpse(dti2)

## variable str----
dti2 <- dti2 %>% mutate_if(is.character, factor) %>% 
  mutate(Block = as.factor(Block),
         Plot = as.factor(Plot),
         fcycle = as.factor(fcycle))
glimpse(dti2)

# Descriptive----
## Cumulative distribution-----
### Ecdf for trt vs damage----
# # Prepare the data for ecdf
# ecdf_gg_KSi4 <- dti2 %>%
#   mutate(Treatments = as.factor(paste0(Si,"_", K_level)))%>%
#   mutate(Treatments = fct_relevel(Treatments,"0Si_0K", "0Si_75K","0Si_150K",
#                                   "0Si_250K","0Si_600K",  "300Si_0K",
#                                   "300Si_75K","300Si_150K")) %>%
#   mutate(K_level = fct_relevel(K_level,"0K", "75K", "150K","250K","600K")) %>%
#   ggplot(aes(x=XT,col=Treatments))+
#   geom_line(stat="myecdf", aes(color = Treatments,linetype = Treatments),
#             size = .6)+
#   facet_grid(~Water) +
#   labs(x = "Weevil damage (%)",y = "Proportion of population") +
#   theme_custom()+
#   scale_colour_manual(name = expression(paste("Treatments (",kg~ha^-1,~yr^-1,")")),
#                      labels = c("0 Si + 0 K", "0 Si + 75 K","0 Si + 150 K",
#                                 "0 Si + 250 K","0 Si + 600 K","300 Si + 0 K",
#                                 "300 Si + 75 K","300 Si + 150 K"),
#                      values= c("#386cb0","#ef3b2c","#7fc97f","#fdb462","black",
#                        "#386cb0","#ef3b2c","#7fc97f"))+
#   scale_linetype_manual(name = expression(paste("Treatments (",kg~ha^-1,~yr^-1,")")),
#                       labels = c("0 Si + 0 K", "0 Si + 75 K","0 Si + 150 K",
#                                  "0 Si + 250 K","0 Si + 600 K","300 Si + 0 K",
#                                  "300 Si + 75 K","300 Si + 150 K"),
#                       values=c("longdash","longdash", "longdash","longdash",
#                                "longdash","solid","solid", "solid"))+
#   theme(text = element_text(family= "sans", size=14),
#         legend.key.width = unit(1, 'cm'),
#         legend.position = c(.8,.38), legend.direction = "vertical",
#         legend.key.size = unit(1.3, 'lines'),
#         panel.background = element_rect(fill = "white"),
#         strip.background = element_rect(fill= "white"),
#         panel.grid.minor = element_blank())
# 
# 
# ecdf_gg_KSi4
# ggsave(plot = ecdf_gg_KSi4,
#        Fig_4,
#        dpi = 600, width = 8, height = 5)


# Red and black plots-----
ecdf_gg_KSi5 <- dti2 %>% filter(Water == "Irrigated") %>% 
  mutate(Treatments = as.factor(paste0(Si,"_", K_level)))%>% 
  mutate(Treatments = fct_relevel(Treatments,"0Si_0K", "0Si_75K","0Si_150K",
                                  "0Si_250K","0Si_600K",  "300Si_0K",
                                  "300Si_75K","300Si_150K")) %>% 
  ggplot(aes(x=XT,col=Treatments))+ 
  geom_line(stat="myecdf", aes(linetype= Treatments, color = Treatments),
            size = .6)+
  labs(x = "Weevil damage (%)",y = "Proportion of population",
       title = "Irrigated") +
  theme_custom()+
  scale_color_manual(name = expression(paste("Treatments (",kg~ha^-1,~yr^-1,")")),
                     labels = c("0 Si + 0 K", "0 Si + 75 K","0 Si + 150 K",
                                "0 Si + 250 K","0 Si + 600 K","300 Si + 0 K",
                                "300 Si + 75 K","300 Si + 150 K"),
                     values=c("black","black","black","black","black","red",
                              "red","red")) +
  scale_linetype_manual(name = expression(paste("Treatments (",kg~ha^-1,~yr^-1,")")),
                        labels = c("0 Si + 0 K", "0 Si + 75 K","0 Si + 150 K",
                                   "0 Si + 250 K","0 Si + 600 K","300 Si + 0 K",
                                   "300 Si + 75 K","300 Si + 150 K"),
                        values= c('solid', 'dashed',"dotdash", "longdash", 
                                  "twodash",'solid', 'dashed',"dotdash")) +
  theme(text = element_text(family= "sans", size=14),
        legend.key.width = unit(1.5, 'cm'),
        legend.position = c(.72,.38), legend.direction = "vertical",
        legend.key.size = unit(1.3, 'lines'),
        panel.background = element_rect(fill = "white"),
        strip.background = element_rect(fill= "white"),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank(),
        axis.title.y = element_blank(),
        axis.text.y = element_blank())


ecdf_gg_KSi6 <- dti2 %>% filter(Water == "Rain-fed") %>% 
  mutate(Treatments = as.factor(paste0(Si,"_", K_level)))%>% 
  mutate(Treatments = fct_relevel(Treatments,"0Si_0K", "0Si_75K","0Si_150K",
                                  "0Si_250K","0Si_600K",  "300Si_0K",
                                  "300Si_75K","300Si_150K")) %>% 
  ggplot(aes(x=XT,col=Treatments))+ 
  geom_line(stat="myecdf", aes(linetype= Treatments, color = Treatments),
            size = .6)+
  labs(x = "Weevil damage (%)",y = "Proportion of population",
       title = "Rain-fed") +
  theme_custom()+
  scale_color_manual(name = expression(paste("Treatments (",kg~ha^-1,~yr^-1,")")),
                     labels = c("0 Si + 0 K", "0 Si + 75 K","0 Si + 150 K",
                                "0 Si + 250 K","0 Si + 600 K","300 Si + 0 K",
                                "300 Si + 75 K","300 Si + 150 K"),
                     values=c("black","black","black","black","black","red",
                              "red","red")) +
  scale_linetype_manual(name = expression(paste("Treatments (",kg~ha^-1,~yr^-1,")")),
                        labels = c("0 Si + 0 K", "0 Si + 75 K","0 Si + 150 K",
                                   "0 Si + 250 K","0 Si + 600 K","300 Si + 0 K",
                                   "300 Si + 75 K","300 Si + 150 K"),
                        values= c('solid', 'dashed',"dotdash", "longdash", 
                                  "twodash",'solid', 'dashed',"dotdash")) +
  theme(text = element_text(family= "sans", size=14),
        legend.position = "none",
        panel.background = element_rect(fill = "white"),
        strip.background = element_rect(fill= "white"),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank())

p <- ecdf_gg_KSi6+ecdf_gg_KSi5
p
ggsave(plot = p,
       Fig_1,
       dpi = 600, width = 8, height = 5)

# Gray and black plots----
ecdf_gg_KSi7 <- dti2 %>% filter(Water == "Irrigated") %>% 
  mutate(Treatments = as.factor(paste0(Si,"_", K_level)))%>% 
  mutate(Treatments = fct_relevel(Treatments,"0Si_0K", "0Si_75K","0Si_150K",
                                  "0Si_250K","0Si_600K",  "300Si_0K",
                                  "300Si_75K","300Si_150K")) %>% 
  ggplot(aes(x=XT,col=Treatments))+ 
  geom_line(stat="myecdf", aes(linetype= Treatments, color = Treatments),
            size = .6)+
  labs(x = "Weevil damage (%)",y = "Proportion of population",
       title = "Irrigated") +
  theme_custom()+
  scale_color_manual(name = expression(paste("Treatments (",kg~ha^-1,~yr^-1,")")),
                     labels = c("0 Si + 0 K", "0 Si + 75 K","0 Si + 150 K",
                                "0 Si + 250 K","0 Si + 600 K","300 Si + 0 K",
                                "300 Si + 75 K","300 Si + 150 K"),
                     values=c("black","black","black","black","black","gray40",
                              "gray40","gray40")) +
  scale_linetype_manual(name = expression(paste("Treatments (",kg~ha^-1,~yr^-1,")")),
                        labels = c("0 Si + 0 K", "0 Si + 75 K","0 Si + 150 K",
                                   "0 Si + 250 K","0 Si + 600 K","300 Si + 0 K",
                                   "300 Si + 75 K","300 Si + 150 K"),
                        values= c('solid', 'dashed',"dotdash", "longdash", 
                                  "twodash",'solid', 'dashed',"dotdash")) +
  theme(text = element_text(family= "sans", size=14),
        legend.key.width = unit(1.5, 'cm'),
        legend.position = c(.72,.38), legend.direction = "vertical",
        legend.key.size = unit(1.3, 'lines'),
        panel.background = element_rect(fill = "white"),
        strip.background = element_rect(fill= "white"),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank(),
        axis.title.y = element_blank(),
        axis.text.y = element_blank())


ecdf_gg_KSi8 <- dti2 %>% filter(Water == "Rain-fed") %>% 
  mutate(Treatments = as.factor(paste0(Si,"_", K_level)))%>% 
  mutate(Treatments = fct_relevel(Treatments,"0Si_0K", "0Si_75K","0Si_150K",
                                  "0Si_250K","0Si_600K",  "300Si_0K",
                                  "300Si_75K","300Si_150K")) %>% 
  ggplot(aes(x=XT,col=Treatments))+ 
  geom_line(stat="myecdf", aes(linetype= Treatments, color = Treatments),
            size = .6)+
  labs(x = "Weevil damage (%)",y = "Proportion of population",
       title = "Rain-fed") +
  theme_custom()+
  scale_color_manual(name = expression(paste("Treatments (",kg~ha^-1,~yr^-1,")")),
                     labels = c("0 Si + 0 K", "0 Si + 75 K","0 Si + 150 K",
                                "0 Si + 250 K","0 Si + 600 K","300 Si + 0 K",
                                "300 Si + 75 K","300 Si + 150 K"),
                     values=c("black","black","black","black","black","gray40",
                              "gray40","gray40")) +
  scale_linetype_manual(name = expression(paste("Treatments (",kg~ha^-1,~yr^-1,")")),
                        labels = c("0 Si + 0 K", "0 Si + 75 K","0 Si + 150 K",
                                   "0 Si + 250 K","0 Si + 600 K","300 Si + 0 K",
                                   "300 Si + 75 K","300 Si + 150 K"),
                        values= c('solid', 'dashed',"dotdash", "longdash", 
                                  "twodash",'solid', 'dashed',"dotdash")) +
  theme(text = element_text(family= "sans", size=14),
        legend.position = "none",
        panel.background = element_rect(fill = "white"),
        strip.background = element_rect(fill= "white"),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank())

p2 <- ecdf_gg_KSi8+ecdf_gg_KSi7
p2
ggsave(plot = p2,
       Fig_2,
       dpi = 600, width = 8, height = 5)