# Notes
# There is a code outline right next to "source" icon. it is a table fo content
# Inputs-----
file_Kawanda_Ntugamo_in <- "./Nutrition_and_weevils/data/processed/2_Potassium_response_trial.csv"

# Outputs----
# Tables
table_out_1  <- "./Nutrition_and_weevils/results/Tables/6_fcycle+Water+K_level+Si.csv"
table_out_1b <- "./Nutrition_and_weevils/results/Tables/6_fcycle+Water+K_level+Si_contrasts.csv"

# Figures
Fig_1 <- "./results/figures/2b_TrtsXcycle on Predicted weevils damage_average cycle.tiff"
Fig_2 <- "./results/figures/2b_"

# visual elements
axis_text <- element_text(color = "black", size = 11)

# Kawanda field trial----
## Import data----
dti2 <- fread(file_Kawanda_Ntugamo_in) 
glimpse(dti2)

## Change str----
dti2 <- dti2 %>% filter(XT < 50) %>% 
  mutate_if(is.character, factor) %>% 
  mutate(Block = as.factor(Block),
         Plot = as.factor(Plot),
         fcycle = as.factor(fcycle),
         matID = as.factor(paste0(Block,"_",Plot,"_",Matno)),
         cycleID = as.factor(paste0(Block,"_",Plot,"_",Matno,"_",fcycle)))

# Inference----
### All treatments----
#### Interactive----
# Order the Trts
levels(dti2$K_level)
dti2$K_level <-   fct_relevel(dti2$K_level,
                           "0K", "75K","150K","250K","600K")

# Negative binomial
# additive vs interactive model
dti2$Trts <-   fct_relevel(dti2$Trts,
                                "Rain-fed_0Si_0K","Rain-fed_0Si_75K",
                                "Rain-fed_0Si_150K","Rain-fed_0Si_250K",
                                "Rain-fed_0Si_600K","Rain-fed_300Si_0K",
                                "Rain-fed_300Si_75K","Rain-fed_300Si_150K",
                                "Irrigated_0Si_0K", "Irrigated_0Si_75K",
                                "Irrigated_0Si_150K","Irrigated_0Si_250K", 
                                "Irrigated_0Si_600K","Irrigated_300Si_0K",
                                "Irrigated_300Si_75K","Irrigated_300Si_150K")

mm5b <- glmmTMB(XT ~ Cycle*Trts+(1|Block/Plot/Mat),
               family = nbinom2, data=dti2)
summary(mm5b)

mm5bb <- glmmTMB(XT ~ Cycle+Trts+(1|Block/Plot/Mat),
                family = nbinom2, data=dti2)
summary(mm5bb)

# the models are not different
anova(mm5b,mm5bb)

# mm5bb (additive is better) is better on AIC
AICtab(mm5b,mm5bb)

# take cycle to dispersion model
mm5c <- glmmTMB(XT ~ Trts+(1|Block/Plot/Mat), disp=~Cycle,
                family = nbinom2, data=dti2)
summary(mm5c)

# mm5c is better than mm5b but mm5bb is still best of 3
AICtab(mm5b,mm5bb,mm5c)

# break up the trts to their factors and order them
levels(dti2$Water)
dti2$Water <-   fct_relevel(dti2$Water,
                            "Rain-fed" ,"Irrigated")
levels(dti2$K_level)
dti2$K_level <-   fct_relevel(dti2$K_level,
                              "0K", "75K","150K","250K","600K")

mm5d <- glmmTMB(XT ~ Water+K_level+Si+(1|Block/Plot/Mat), disp=~Cycle,
                family = nbinom2, data=dti2)
summary(mm5d)

# put cycle as fixed
mm5dd <- glmmTMB(XT ~ Cycle+Water+K_level+Si+(1|Block/Plot/Mat),
                family = nbinom2, data=dti2)
summary(mm5dd)

# put cycle as fixed and factor
mm5ddii <- glmmTMB(XT ~ fcycle+Water+K_level+Si+(1|Block/Plot/Mat),
                 family = nbinom2, data=dti2)
summary(mm5ddii)

# mm5d is significantly different from mm5dd
anova(mm5d,mm5dd)

# mm5d is significantly different from mm5dd
anova(mm5bb,mm5dd)

# mm5ddiii is better
AICtab(mm5d, mm5dd, mm5ddii)

# try with factors works
mm5e <- glmmTMB(XT ~ Water*(K_level+Si)+(1|Block/Plot/Mat), disp=~Cycle,
              family = nbinom2, data=dti2)
summary(mm5e)

# compare models
AICtab(mm5b,mm5c,mm5e,mm5bb, mm5d, mm5dd,mm5ddii)

# put cycle as fixed and factor
mm5ddii <- glmmTMB(XT ~ fcycle+Water+K_level+Si+(1|Block/Plot/Mat),
                   family = nbinom2, data=dti2)
summary(mm5ddii)

# look at the of residuals
simulationOutput <- DHARMa::simulateResiduals(fittedModel = mm5ddii, plot = F)
plotQQunif(simulationOutput)
testZeroInflation(simulationOutput)
testOutliers(simulationOutput, type = "bootstrap")

# REML
mm5ddii_reml <- glmmTMB(XT ~ fcycle+Water+K_level+Si+(1|Block/Plot/Mat),
                   family = nbinom2, REML = TRUE, data=dti2)
summary(mm5ddii_reml)
summ <- summary(mm5ddii_reml)
summ$sigma
# look at dispersion factor
disp <- testDispersion(mm5ddii_reml) %>% tidy() %>%
  .[1,1]; disp  # close to one

# bind regression with disp and save them
cbind(broom.mixed::tidy(mm5ddii_reml),disp) %>%
  fwrite(., table_out_1)

#### Contrasts on mm5ddiii----
mm5ddii_reml_contrasts <- glht(mm5ddii_reml, linfct=mcp(K_level="Tukey"))
mm5ddii_reml_contrasts2 <- summary(mm5ddii_reml_contrasts)
mm5ddii_reml_contrasts2
broom.mixed::tidy(mm5ddii_reml_contrasts2) %>% 
  fwrite(., table_out_1b)
